@@ -1,6 +1,7 @@
 from luna.baseLunaUtils import BaseLunaUtils
 from mlflow.pyfunc import PythonModel, PythonModelContext
 from mlflow.tracking.client import MlflowClient
+from luna.logging.mlflowLunaLogger import MLFlowLunaLogger
 
 import mlflow
 import os
@@ -17,6 +18,8 @@ class MLflowLunaUtils(BaseLunaUtils):
             with open(self._luna_config["mlflow"]["test_experiment"]) as file:
                 test_exp = yaml.full_load(file)
                 mlflow.start_run(experiment_id=test_exp["experiment_id"])
+        
+        self._logger = MLFlowLunaLogger()
 
     def RegisterModel(self, model_path, description, luna_python_model=None):
         mlFlowRun = mlflow.active_run()
